@@ -11,8 +11,4 @@ class CautionHourType(Enum):
     Aggressive = CAUTIONHOURTYPE_AGGRESSIVE
 
 
-ttt = CautionHourType(CAUTIONHOURTYPE_SUAVE)
-#detta är enumvärdet
-print(ttt.name)
-#detta är strängen
-print(ttt.value)
\ No newline at end of file
+ttt = CautionHourType(CAUTIONHOURTYPE_SUAVE)
\ No newline at end of file
