@@ -79,8 +79,21 @@ class HourSelectionOptions:
 class HourSelectionModel:
     prices_today: List[float] = field(default_factory=lambda : [])
     prices_tomorrow: List[float] = field(default_factory=lambda : [])
+    adjusted_average: float = None
+    current_peak: float = 0.0
     hours: HoursModel = HoursModel()
     options: HourSelectionOptions = HourSelectionOptions
 
+    def __post_init__(self):
+        self.validate()
+
     def validate(self):
-        assert 0 < self.options.cautionhour_type <= 1
\ No newline at end of file
+        assert 0 < self.options.cautionhour_type <= 1
+        assert isinstance(self.prices_today, list)
+        assert isinstance(self.prices_tomorrow, list)
+
+        if isinstance(self.adjusted_average, (int, float)):
+            assert self.adjusted_average >= 0
+        else:
+            assert self.adjusted_average is None
+        
\ No newline at end of file
