@@ -1,19 +1,40 @@
+from __future__ import annotations
 import logging
+from typing import Tuple
 from ...util import nametoid
 
 _LOGGER = logging.getLogger(__name__)
 
 
 class HubMember:
-    def __init__(self, data_type, listenerentity = None, initval = None, name = None, init_override:bool = False):
+    def __init__(
+        self, 
+        data_type, 
+        listenerentity = None, 
+        initval = None, 
+        name = None, 
+        init_override:bool = False
+        ):
         self._value = initval
         self._type = data_type
-        self._listenerentity = listenerentity
+        self._listenerentity, self._listenerattribute = self._set_listeners(listenerentity)
         self.name = name
         self.id = nametoid(self.name) if self.name is not None else None
         self.warned_not_initialized = False
         self._is_initialized = init_override
 
+    def _set_listeners(self, listenerentity:str|None) -> Tuple[str, str|None]:
+        if listenerentity is None:
+            return None, None
+        try:
+            _arr = listenerentity.split('|')
+            if len(_arr) == 1:
+                return listenerentity, None
+            return _arr[0], _arr[1]
+        except:
+            _LOGGER.debug(f"could not handle this listenerentity in split-setup: {listenerentity}")
+            return None, None
+
     @property
     def is_initialized(self) -> bool:
         if self._is_initialized:
@@ -35,6 +56,14 @@ class HubMember:
     def entity(self, val: str):
         self._listenerentity = val
 
+    @property
+    def use_attribute(self) -> bool:
+        return self._listenerattribute is not None
+
+    @property
+    def attribute(self) -> str:
+        return self._listenerattribute
+
     @property
     def value(self):
         return self._value
