@@ -17,6 +17,7 @@ CHARGERSTATES_BASE = {
 @dataclass
 class ChargerBase:
     domainname:str = ""
+    max_amps = 16 #base-number if nothing else is spawned from the chargertype
     native_chargerstates:list = field(default_factory=lambda: [])
     servicecalls:ServiceCalls = None
     chargerstates = CHARGERSTATES_BASE
@@ -31,6 +32,10 @@ class ChargerBase:
     ) -> None:
         self.servicecalls = ServiceCalls(domain, model, options)
 
+    @abstractmethod
+    def get_allowed_amps(self) -> int:
+        pass
+
     @abstractmethod
     def validatecharger(self) -> bool:
         pass
