@@ -18,7 +18,7 @@ class PriceAwareHours(Hours):
         self._core = core_hours(
             self._set_absolute_top_price(hub.options.price.top_price),
             hub.options.price.min_price,
-            self._cautionhour_type, hub.options.price.allow_top_up
+            self._cautionhour_type
         )
         self._hass = hub.state_machine
         self._prices = []
@@ -26,7 +26,7 @@ class PriceAwareHours(Hours):
 
     @property
     def options(self):
-        return self._core.options
+        return self._core.model.options
 
     @property
     def dynamic_caution_hours(self) -> dict:
