@@ -245,4 +245,21 @@ class SE_Malarenergi(Locale_Type):
     
     """
     Det högre priset gäller bara på helgfria vardagar 07.00-20.00 under november till mars.
-    """
\ No newline at end of file
+    """
+
+@dataclass(frozen=True)
+class SE_TekniskaVerken_Link(Locale_Type):
+    observed_peak = QUERYTYPE_BASICMAX
+    charged_peak = QUERYTYPE_BASICMAX
+    query_model = QUERYTYPES[QUERYTYPE_BASICMAX]
+
+    #docs: unknown
+
+@dataclass(frozen=True)
+class SE_Eskilstuna(Locale_Type):
+    observed_peak = QUERYTYPE_BASICMAX
+    charged_peak = QUERYTYPE_BASICMAX
+    query_model = QUERYTYPES[QUERYTYPE_BASICMAX]
+
+    #docs: unknown
+    
\ No newline at end of file
