@@ -29,7 +29,8 @@ class SessionPrice:
     def total_energy(self) -> float:
         return round(self.get_status()["energy"]["value"], 3)
 
-    def reset(self):
+    def reset(self): #add inputparams here
+        #push a heartbeat to the api
         self.__init__(self.average_data.export)
 
     def terminate(self, mock_time: float=None):
